@@ -23,28 +23,34 @@ netposet <- function(..., outcomes, treatments, small.values,
     ## (1) Check arguments
     ##
     if (!(is.matrix(args[[1]]) | is.data.frame(args[[1]])))
-      stop("First argument must be a matrix or data frame if only a single argument is provided.",
+      stop("First argument must be a matrix or ",
+           "data frame if only a single argument is provided.",
            call. = FALSE)
     ##
     if (!missing(small.values))
-      warning("Argument 'small.values' is ignored as first argument is a ranking matrix.")
+      warning("Argument 'small.values' is ignored as first argument ",
+              "is a ranking matrix.",
+              call. = FALSE)
     ##
     pscore.matrix <- args[[1]]
     ##
     if (any(pscore.matrix[!is.na(pscore.matrix)] > 1) |
         any(pscore.matrix[!is.na(pscore.matrix)] < 0))
-      stop("All elements of ranking matrix must be between 0 and 1.")
+      stop("All elements of ranking matrix must be between 0 and 1.",
+           call. = FALSE)
     ##
     n.outcomes <- ncol(pscore.matrix)
     n.treatments <- nrow(pscore.matrix)
     ##
     if (n.outcomes == 1)
-      stop("Minimum number of two outcomes (equal to number of columns of ranking matrix).",
+      stop("Minimum number of two outcomes ",
+           "(equal to number of columns of ranking matrix).",
            call. = FALSE)
     ##
     if (!missing(outcomes)) {
       if (length(outcomes) != n.outcomes)
-        stop("Number of outcomes provided by argument 'outcomes' is different from number of columns of ranking matrix.",
+        stop("Number of outcomes provided by argument 'outcomes' ",
+             "is different from number of columns of ranking matrix.",
              call. = FALSE)
     }
     else
@@ -52,7 +58,8 @@ netposet <- function(..., outcomes, treatments, small.values,
     ##
     if (!missing(treatments)) {
       if (length(treatments) != n.treatments)
-        stop("Number of treatments provided by argument 'treatments' is different from number of rows of ranking matrix.",
+        stop("Number of treatments provided by argument 'treatments' ",
+             "is different from number of rows of ranking matrix.",
              call. = FALSE)
     }
     else
@@ -62,13 +69,15 @@ netposet <- function(..., outcomes, treatments, small.values,
     ##
     if (is.null(outcomes)) {
       warning("Outcomes are labelled 'A' to '", LETTERS[n.outcomes],
-              "' as argument 'outcomes' is missing and column names are NULL.")
+              "' as argument 'outcomes' is missing and column names are NULL.",
+              call. = FALSE)
       outcomes <- LETTERS[1:n.outcomes]
     }
     ##
     if (is.null(treatments)) {
       warning("Treatments are labelled 'a' to '", letters[n.treatments],
-              "' as row names are NULL.")
+              "' as row names are NULL.",
+              call. = FALSE)
       treatments <- letters[1:n.treatments]
     }
     ##
@@ -93,16 +102,20 @@ netposet <- function(..., outcomes, treatments, small.values,
     n.outcomes <- length(args)
     ##
     if (!missing(treatments))
-      warning("Argument 'treatments' ignored (only needed if first argument is a ranking matrix).")
+      warning("Argument 'treatments' ignored (only needed if ",
+              "first argument is a ranking matrix).",
+              call. = FALSE)
     ##
     if (missing(outcomes)) {
       warning("Outcomes are labelled 'A' to '", LETTERS[n.outcomes],
-              "' as argument 'outcomes' is missing.")
+              "' as argument 'outcomes' is missing.",
+              call. = FALSE)
       outcomes <- LETTERS[1:n.outcomes]  
     }
     ##
     if (length(outcomes) != n.outcomes)
-      stop("Number of outcomes provided by argument 'outcomes' and number of rankings differ.",
+      stop("Number of outcomes provided by argument 'outcomes' ",
+           "and number of rankings differ.",
            call. = FALSE)
     ##
     for (i in seq_along(args)) {
@@ -111,20 +124,25 @@ netposet <- function(..., outcomes, treatments, small.values,
       else if (inherits(args[[i]], "netrank"))
         any.netrank <- TRUE
       else
-        stop("All elements of argument '...' must be of class 'netmeta' or 'netrank'.",
+        stop("All elements of argument '...' must be of class ",
+             "'netmeta' or 'netrank'.",
              call. = FALSE)
       ##
       if (!missing(small.values))
         small.values <- meta:::setchar(small.values, c("good", "bad"))
       else {
         if (any.netmeta)
-          warning("R function netrank() called internally with argument small.values = 'good' as argument 'small.values' is missing.")
+          warning("R function netrank() called internally with argument ",
+                  "small.values = 'good' as argument 'small.values' ",
+                  "is missing.",
+                  call. = FALSE)
         small.values <- rep("good", n.outcomes)
       }
       ##
       if (length(small.values) != n.outcomes)
-        stop("Length of argument 'small.values' must be equal to number of outcomes.",
-             call. = TRUE)
+        stop("Length of argument 'small.values' must be equal to ",
+             "number of outcomes.",
+             call. = FALSE)
     }
     ##
     ## (2) Extract P-Scores
@@ -137,15 +155,19 @@ netposet <- function(..., outcomes, treatments, small.values,
       args.i <- args[[i]]
       ##
       if (inherits(args.i, "netmeta")) {
-        pscore.list.fixed[[i]] <- netrank(args.i, small.values = small.values[i])$Pscore.fixed
-        pscore.list.random[[i]] <- netrank(args.i, small.values = small.values[i])$Pscore.random
-        comb.fixeds[i] <- args.i$comb.fixed
+        pscore.list.fixed[[i]] <- netrank(args.i,
+                                          small.values =
+                                            small.values[i])$Pscore.fixed
+        pscore.list.random[[i]] <- netrank(args.i,
+                                           small.values =
+                                             small.values[i])$Pscore.random
+        comb.fixeds[i]  <- args.i$comb.fixed
         comb.randoms[i] <- args.i$comb.random
       }
       else if (inherits(args.i, "netrank")) {
         pscore.list.fixed[[i]] <- args.i$Pscore.fixed
         pscore.list.random[[i]] <- args.i$Pscore.random
-        comb.fixeds[i] <- args.i$x$comb.fixed
+        comb.fixeds[i]  <- args.i$x$comb.fixed
         comb.randoms[i] <- args.i$x$comb.random
       }
     }
@@ -166,7 +188,8 @@ netposet <- function(..., outcomes, treatments, small.values,
         missing.j <- !(treatments %in% treatments.j)
         ##
         if (any(treatments.j != treatments[!missing.j]))
-          stop("Treatment names of all rankings must be in same order.")
+          stop("Treatment names of all rankings must be in same order.",
+               call. = FALSE)
         ##
         pscore.j <- pscore.list.fixed[[j]]
         pscore.list.fixed[[j]] <- pscore.list.fixed[[sel.max]]
@@ -223,8 +246,9 @@ netposet <- function(..., outcomes, treatments, small.values,
     if (missing(comb.fixed)) {
       comb.fixed <- unique(comb.fixeds)
       if (length(comb.fixed) != 1) {
-        warning("Argument 'comb.fixed' set to TRUE as different values are available in",
-                text.netmeta.netrank)
+        warning("Argument 'comb.fixed' set to TRUE as different values are ",
+                "available in ", text.netmeta.netrank,
+                call. = FALSE)
         comb.fixed <- TRUE
       }
     }
@@ -232,16 +256,17 @@ netposet <- function(..., outcomes, treatments, small.values,
     if (missing(comb.random)) {
       comb.random <- unique(comb.randoms)
       if (length(comb.random) != 1) {
-        warning("Argument 'comb.random' set to TRUE as different values are available in",
-                text.netmeta.netrank)
+        warning("Argument 'comb.random' set to TRUE as different values are ",
+                "available in ", text.netmeta.netrank,
+                call. = FALSE)
         comb.random <- TRUE
       }
     }
   } 
   
   
-  n <- dim(pscore.matrix.fixed)[1]
-  o <- dim(pscore.matrix.fixed)[2]
+  n <- nrow(pscore.matrix.fixed)
+  o <- ncol(pscore.matrix.fixed)
   
   
   Pos.fixed <- M.fixed <- matrix(0, nrow = n, ncol = n)
@@ -255,30 +280,31 @@ netposet <- function(..., outcomes, treatments, small.values,
   rownames(M.random) <- colnames(M.random) <- rownames(pscore.matrix.random)
   
   
-  ## Pos[i, j] counts how many rankings judge treatment i superior to treatment j
-  ## (number between 0 and o)
+  ## Pos[i, j] counts how many rankings judge treatment i superior to
+  ## treatment j (number between 0 and o)
   ##
   for (i in 1:n)
     for (j in 1:n)
-      for (k in 1:o)
-        if (!is.na(pscore.matrix.fixed[i,k]) &
-            !is.na(pscore.matrix.fixed[j,k]) &
-            pscore.matrix.fixed[i, k] > pscore.matrix.fixed[j, k])
-          Pos.fixed[i, j] <- Pos.fixed[i, j] + 1
+      if (i != j)
+        for (k in 1:o)
+          if (!is.na(pscore.matrix.fixed[i, k]) &
+              !is.na(pscore.matrix.fixed[j, k]) &
+              pscore.matrix.fixed[i, k] >= pscore.matrix.fixed[j, k])
+            Pos.fixed[i, j] <- Pos.fixed[i, j] + 1
   ##
   for (i in 1:n)
     for (j in 1:n)
-      for (k in 1:o)
-        if (!is.na(pscore.matrix.random[i,k]) &
-            !is.na(pscore.matrix.random[j,k]) &
-            pscore.matrix.random[i, k] > pscore.matrix.random[j, k])
-          Pos.random[i, j] <- Pos.random[i, j] + 1
+      if (i != j)
+        for (k in 1:o)
+          if (!is.na(pscore.matrix.random[i, k]) &
+              !is.na(pscore.matrix.random[j, k]) &
+              pscore.matrix.random[i, k] >= pscore.matrix.random[j, k])
+            Pos.random[i, j] <- Pos.random[i, j] + 1
   
   
   ## Calculate "full" Hasse matrix M
   ##
-  M.fixed[Pos.fixed == o] <- 1
-  ##
+  M.fixed[Pos.fixed == o]   <- 1
   M.random[Pos.random == o] <- 1
   
   
