@@ -1,5 +1,8 @@
 prepare <- function(TE, seTE, treat1, treat2, studlab, tau = 0) {
   
+  if (is.na(tau))
+    tau <- 0
+  
   weights <- 1 / (seTE^2 + tau^2)
   
   data <- data.frame(studlab,
